@@ -30,18 +30,22 @@
  *   Returns information about the image data file
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config_auto.h>
+#endif  /* HAVE_CONFIG_H */
+
 #include "allheaders.h"
 
 int main(int    argc,
          char **argv)
 {
-char        *filein;
-static char  mainName[] = "fileinfo";
+char  *filein;
 
     if (argc != 2)
-        return ERROR_INT(" Syntax:  fileinfo filein", mainName, 1);
+        return ERROR_INT(" Syntax:  fileinfo filein", __func__, 1);
     filein = argv[1];
 
+    setLeptDebugOK(1);
     writeImageFileInfo(filein, stderr, 0);
     return 0;
 }
