@@ -61,20 +61,19 @@ static const l_int32  MAX_WORD_HEIGHT = 200;
 int main(int    argc,
          char **argv)
 {
-char         filename[BUF_SIZE];
-char        *dirin, *rootname;
-l_int32      reduction, i, firstpage, npages;
-l_float32    thresh, weight;
-JBDATA      *data;
-JBCLASSER   *classer;
-NUMA        *natl;
-PIX         *pix;
-PIXA        *pixa, *pixadb;
-static char  mainName[] = "jbwords";
+char        filename[BUF_SIZE];
+char       *dirin, *rootname;
+l_int32     reduction, i, firstpage, npages;
+l_float32   thresh, weight;
+JBDATA     *data;
+JBCLASSER  *classer;
+NUMA       *natl;
+PIX        *pix;
+PIXA       *pixa, *pixadb;
 
     if (argc != 6 && argc != 8)
         return ERROR_INT(" Syntax: jbwords dirin reduction thresh "
-                         "weight rootname [firstpage, npages]", mainName, 1);
+                         "weight rootname [firstpage, npages]", __func__, 1);
     dirin = argv[1];
     reduction = atoi(argv[2]);
     thresh = atof(argv[3]);
@@ -105,7 +104,7 @@ static char  mainName[] = "jbwords";
     for (i = 0; i < npages; i++) {
         pix = pixaGetPix(pixa, i, L_CLONE);
         snprintf(filename, BUF_SIZE, "%s.%05d", rootname, i);
-        fprintf(stderr, "filename: %s\n", filename);
+        lept_stderr("filename: %s\n", filename);
         pixWrite(filename, pix, IFF_PNG);
         pixDestroy(&pix);
     }
@@ -120,7 +119,7 @@ static char  mainName[] = "jbwords";
     for (i = 0; i < npages; i++) {
         pix = pixaGetPix(pixadb, i, L_CLONE);
         snprintf(filename, BUF_SIZE, "%s.db.%05d", rootname, i);
-        fprintf(stderr, "filename: %s\n", filename);
+        lept_stderr("filename: %s\n", filename);
         pixWrite(filename, pix, IFF_PNG);
         pixDestroy(&pix);
     }
