@@ -55,13 +55,20 @@
  *          SELA    *sela4ccThin()
  *          SELA    *sela8ccThin()
  *          SELA    *sela4and8ccThin()
+ *
+ *      Other structuring elements
+ *          SEL    *selMakePlusSign()
  * </pre>
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config_auto.h>
+#endif  /* HAVE_CONFIG_H */
+
 #include <math.h>
 #include "allheaders.h"
 
-static const l_int32  L_BUF_SIZE = 512;
+#define L_BUF_SIZE 512
 
     /* Linear brick sel sizes, including all those that are required
      * for decomposable sels up to size 63. */
@@ -95,11 +102,9 @@ char     name[L_BUF_SIZE];
 l_int32  i, size;
 SEL     *sel;
 
-    PROCNAME("selaAddBasic");
-
     if (!sela) {
         if ((sela = selaCreate(0)) == NULL)
-            return (SELA *)ERROR_PTR("sela not made", procName, NULL);
+            return (SELA *)ERROR_PTR("sela not made", __func__, NULL);
     }
 
     /*--------------------------------------------------------------*
@@ -182,11 +187,9 @@ selaAddHitMiss(SELA  *sela)
 {
 SEL  *sel;
 
-    PROCNAME("selaAddHitMiss");
-
     if (!sela) {
         if ((sela = selaCreate(0)) == NULL)
-            return (SELA *)ERROR_PTR("sela not made", procName, NULL);
+            return (SELA *)ERROR_PTR("sela not made", __func__, NULL);
     }
 
 #if 0   /*  use just for testing */
@@ -322,11 +325,9 @@ char     name[L_BUF_SIZE];
 l_int32  i;
 SEL     *sel;
 
-    PROCNAME("selaAddDwaLinear");
-
     if (!sela) {
         if ((sela = selaCreate(0)) == NULL)
-            return (SELA *)ERROR_PTR("sela not made", procName, NULL);
+            return (SELA *)ERROR_PTR("sela not made", __func__, NULL);
     }
 
     for (i = 2; i < 64; i++) {
@@ -364,11 +365,9 @@ char     name[L_BUF_SIZE];
 l_int32  i, f1, f2, prevsize, size;
 SEL     *selh, *selv;
 
-    PROCNAME("selaAddDwaCombs");
-
     if (!sela) {
         if ((sela = selaCreate(0)) == NULL)
-            return (SELA *)ERROR_PTR("sela not made", procName, NULL);
+            return (SELA *)ERROR_PTR("sela not made", __func__, NULL);
     }
 
     prevsize = 0;
@@ -378,11 +377,19 @@ SEL     *selh, *selv;
         if (size == prevsize)
             continue;
         selectComposableSels(i, L_HORIZ, NULL, &selh);
+        if (selh) {
+            snprintf(name, L_BUF_SIZE, "sel_comb_%dh", size);
+            selaAddSel(sela, selh, name, 0);
+        } else {
+            L_ERROR("selh not made for i = %d\n", __func__, i);
+        }
         selectComposableSels(i, L_VERT, NULL, &selv);
-        snprintf(name, L_BUF_SIZE, "sel_comb_%dh", size);
-        selaAddSel(sela, selh, name, 0);
-        snprintf(name, L_BUF_SIZE, "sel_comb_%dv", size);
-        selaAddSel(sela, selv, name, 0);
+        if (selv) {
+            snprintf(name, L_BUF_SIZE, "sel_comb_%dv", size);
+            selaAddSel(sela, selv, name, 0);
+        } else {
+            L_ERROR("selv not made for i = %d\n", __func__, i);
+        }
         prevsize = size;
     }
 
@@ -435,16 +442,14 @@ PIXA      *pixa;
 PTA       *pta1, *pta2, *pta3, *pta4;
 SEL       *sel;
 
-    PROCNAME("selaAddCrossJunctions");
-
     if (hlsize <= 0)
-        return (SELA *)ERROR_PTR("hlsize not > 0", procName, NULL);
+        return (SELA *)ERROR_PTR("hlsize not > 0", __func__, NULL);
     if (norient < 1 || norient > 8)
-        return (SELA *)ERROR_PTR("norient not in [1, ... 8]", procName, NULL);
+        return (SELA *)ERROR_PTR("norient not in [1, ... 8]", __func__, NULL);
 
     if (!sela) {
         if ((sela = selaCreate(0)) == NULL)
-            return (SELA *)ERROR_PTR("sela not made", procName, NULL);
+            return (SELA *)ERROR_PTR("sela not made", __func__, NULL);
     }
 
     pi = 3.1415926535;
@@ -560,16 +565,14 @@ PIXA      *pixa;
 PTA       *pta1, *pta2, *pta3;
 SEL       *sel;
 
-    PROCNAME("selaAddTJunctions");
-
     if (hlsize <= 2)
-        return (SELA *)ERROR_PTR("hlsizel not > 1", procName, NULL);
+        return (SELA *)ERROR_PTR("hlsizel not > 1", __func__, NULL);
     if (norient < 1 || norient > 8)
-        return (SELA *)ERROR_PTR("norient not in [1, ... 8]", procName, NULL);
+        return (SELA *)ERROR_PTR("norient not in [1, ... 8]", __func__, NULL);
 
     if (!sela) {
         if ((sela = selaCreate(0)) == NULL)
-            return (SELA *)ERROR_PTR("sela not made", procName, NULL);
+            return (SELA *)ERROR_PTR("sela not made", __func__, NULL);
     }
 
     pi = 3.1415926535;
@@ -842,3 +845,39 @@ SEL  *sel;
     return sela;
 }
 
+
+/* -------------------------------------------------------------------------- *
+ *                        Other structuring elements                          *
+ * -------------------------------------------------------------------------- */
+/*!
+ * \brief   selMakePlusSign()
+ *
+ * \param[in]    size        side of containing square
+ * \param[in]    linewidth   of lines
+ * \return  sel, or NULL on error
+ *
+ * <pre>
+ * Notes:
+ *      (1) Useful for debugging to show location of selected pixels.
+ *      (2) See displaySelectedPixels() for an example of use.
+ * </pre>
+ */
+SEL *
+selMakePlusSign(l_int32  size,
+                l_int32  linewidth)
+{
+PIX  *pix;
+SEL  *sel;
+
+    if (size < 3 || linewidth > size)
+        return (SEL *)ERROR_PTR("invalid input", __func__, NULL);
+
+    pix = pixCreate(size, size, 1);
+    pixRenderLine(pix, size / 2, 0, size / 2, size - 1,
+                  linewidth, L_SET_PIXELS);
+    pixRenderLine(pix, 0, size / 2, size, size / 2,
+                  linewidth, L_SET_PIXELS);
+    sel = selCreateFromPix(pix, size / 2, size / 2, "plus_sign");
+    pixDestroy(&pix);
+    return sel;
+}
